import { Component } from '@angular/core';
import { IonBackButton, IonButton, IonButtons, IonContent, IonHeader, IonIcon, IonTitle, IonToolbar } from '@ionic/angular/standalone';
import { IonTextarea } from '@ionic/angular/standalone';
import { FmodeChatCompletion, MarkdownPreviewModule } from 'fmode-ng';
import { FormsModule } from '@angular/forms';
import { addIcons } from 'ionicons';
import { bulbOutline, gitNetworkOutline } from 'ionicons/icons';

@Component({
  selector: 'app-interest-test',
  templateUrl: './interest-test.component.html',
  styleUrls: ['./interest-test.component.scss'],
  standalone: true,
  imports: [
    IonHeader,
    IonToolbar,
    IonTitle,
    IonContent,
    IonButton,
    IonTextarea,
    IonIcon,
    FormsModule,
    MarkdownPreviewModule,
    IonBackButton,
    IonButtons,
  ],
})
export class InterestTestComponent {
  userQuestion: string = '';
  responseMsg: string = '';
  isExpand: boolean = false;
  isLoading: boolean = false;

  constructor() {
    addIcons({ bulbOutline, gitNetworkOutline });
  }

  getProblemSolution() {
    if (!this.userQuestion.trim()) {
      this.showToast('请输入您的问题');
      return;
    }

    this.isExpand = false;
    this.isLoading = true;
    this.responseMsg = '';
    const promptTemplate = `
    作为一个专业的问题解决专家，请针对用户的问题提供详细的解决方案。
    用户问题：${this.userQuestion}
    
    请按照以下格式回答：
    1. 问题分析
    2. 解决步骤
    3. 注意事项
    4. 建议与总结
    `;

    this.sendCompletion(promptTemplate);
  }

  getRelatedProblems() {
    if (!this.userQuestion.trim()) {
      this.showToast('请输入您的问题');
      return;
    }

    this.isExpand = true;
    this.isLoading = true;
    this.responseMsg = '';
    const promptTemplate = `
    基于用户提出的问题，请列出5个相关的延伸问题，帮助用户更全面地了解这个领域。
    用户问题：${this.userQuestion}
    
    请按照以下格式回答：
    1. 核心问题概述
    2. 相关延伸问题（5个）
    3. 学习建议
    `;

    this.sendCompletion(promptTemplate);
  }

  private sendCompletion(prompt: string) {
    console.log('开始生成回答...');
    const completion = new FmodeChatCompletion([
      { role: "system", content: "你是一个专业的问题解决和知识拓展专家" },
      { role: "user", content: prompt }
    ]);

    completion.sendCompletion().subscribe({
      next: (message: any) => {
        console.log('正在生成:', message.content.length, '字符');
        this.responseMsg = this.formatResponse(message.content);
      },
      error: (error) => {
        console.error('生成错误:', error);
        this.showToast('生成回答时出现错误，请重试');
        this.isLoading = false;
      },
      complete: () => {
        console.log('生成完成');
        this.isLoading = false;
      }
    });
  }

  private formatResponse(content: string): string {
    content = content.replace(/^(\d+\.|#)\s*(.+)$/gm, '**$2**');

    content = content.replace(/\n(?=\n)/g, '\n\n');

    content = content.replace(/^[-*]\s+/gm, '• ');

    return content;
  }

  private async showToast(message: string) {
    const toast = document.createElement('ion-toast');
    toast.message = message;
    toast.duration = 2000;
    toast.position = 'top';
    document.body.appendChild(toast);
    await toast.present();
  }
}
